15.14. cdist-type__chroot_mount(7) — cdist 4.10.4 documentation

# 15.14. cdist-type__chroot_mount(7)

## 15.14.1. NAME

cdist-type__chroot_mount - mount a chroot

## 15.14.2. DESCRIPTION

Mount and prepare a chroot for running commands within it.

## 15.14.3. REQUIRED PARAMETERS

None

## 15.14.4. OPTIONAL PARAMETERS

manage-resolv-conf
  manage /etc/resolv.conf inside the chroot. Use the value of this parameter as the suffix to save a copy of the current /etc/resolv.conf to /etc/resolv.conf.$suffix. This is used by the __chroot_umount type to restore the initial file content when unmounting the chroot.

## 15.14.5. BOOLEAN PARAMETERS

None.

## 15.14.6. EXAMPLES

    __chroot_mount /path/to/chroot

    __chroot_mount /path/to/chroot \
      --manage-resolv-conf "some-known-string"

## 15.14.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 15.14.8. COPYING

Copyright (C) 2012-2017 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.